@@ -35,8 +35,22 @@ test_that("predict_query mocked call success (bulk async)", {
   stub(predict_query, "poll_model_query", mocks$poll)
   stub(predict_query, "get_json", mocks$get_json)
 
-  test_query <- get_valid_query()
-  results <- predict_query(query = test_query, as_counts = TRUE)
+  test_query <- list(
+    inputs = list(
+      list(
+        metadata = list(
+          cell_type_ontology_id = "CL:0000786",
+          tissue_ontology_id = "UBERON:0001155",
+          sex = "male",
+          sample_type = "primary tissue"
+        ),
+        num_samples = 5
+      )
+    ),
+    mode = "mean estimation",
+    seed = 11
+  )
+  results <- predict_query(query = test_query, model_id = "gem-1-bulk")
 
   expect_type(results, "list")
   expect_true("metadata" %in% names(results))
@@ -86,8 +100,23 @@ test_that("predict_query new API structure handling (bulk)", {
   stub(predict_query, "poll_model_query", mocks$poll)
   stub(predict_query, "get_json", mocks$get_json)
 
-  query <- get_valid_query()
-  results <- predict_query(query, as_counts = TRUE)
+  query <- list(
+    inputs = list(
+      list(
+        metadata = list(
+          age_years = "65",
+          disease_ontology_id = "MONDO:0011719",
+          sex = "female",
+          sample_type = "primary tissue",
+          tissue_ontology_id = "UBERON:0000945"
+        ),
+        num_samples = 1
+      )
+    ),
+    mode = "mean estimation",
+    seed = 11
+  )
+  results <- predict_query(query, model_id = "gem-1-bulk")
 
   expect_true("metadata" %in% names(results))
   expect_true("expression" %in% names(results))
@@ -122,8 +151,21 @@ test_that("predict_query single-cell success (mocked)", {
   stub(predict_query, "poll_model_query", mocks$poll)
   stub(predict_query, "get_json", mocks$get_json)
 
-  query <- get_valid_query(modality = "single-cell")
-  result <- predict_query(query)
+  query <- list(
+    inputs = list(
+      list(
+        metadata = list(
+          cell_type_ontology_id = "CL:0000786",
+          tissue_ontology_id = "UBERON:0001155",
+          sex = "male"
+        ),
+        num_samples = 5
+      )
+    ),
+    mode = "mean estimation",
+    seed = 11
+  )
+  result <- predict_query(query, model_id = "gem-1-sc")
 
   expect_true("metadata" %in% names(result))
   expect_true("expression" %in% names(result))
@@ -146,10 +188,23 @@ test_that("predict_query single-cell failure (mocked)", {
   stub(predict_query, "start_model_query", mocks$start_query)
   stub(predict_query, "poll_model_query", mocks$poll)
 
-  query <- get_valid_query(modality = "single-cell")
+  query <- list(
+    inputs = list(
+      list(
+        metadata = list(
+          cell_type_ontology_id = "CL:0000786",
+          tissue_ontology_id = "UBERON:0001155",
+          sex = "male"
+        ),
+        num_samples = 5
+      )
+    ),
+    mode = "mean estimation",
+    seed = 11
+  )
 
   expect_error(
-    predict_query(query),
+    predict_query(query, model_id = "gem-1-sc"),
     "Model query failed.*missing required field"
   )
 })
@@ -164,11 +219,25 @@ test_that("predict_query single-cell timeout (mocked)", {
   stub(predict_query, "start_model_query", mocks$start_query)
   stub(predict_query, "poll_model_query", mocks$poll)
 
-  query <- get_valid_query(modality = "single-cell")
+  query <- list(
+    inputs = list(
+      list(
+        metadata = list(
+          cell_type_ontology_id = "CL:0000786",
+          tissue_ontology_id = "UBERON:0001155",
+          sex = "male"
+        ),
+        num_samples = 5
+      )
+    ),
+    mode = "mean estimation",
+    seed = 11
+  )
 
   expect_error(
     predict_query(
       query,
+      model_id = "gem-1-sc",
       poll_interval_seconds = 0,
       poll_timeout_seconds = 0
     ),
@@ -177,192 +246,47 @@ test_that("predict_query single-cell timeout (mocked)", {
 })
 
 # -----------------------------
-# Validation Tests
+# New API Function Tests
 # -----------------------------
 
-test_that("get_valid_modalities returns correct structure", {
-  modalities <- get_valid_modalities()
-  expect_type(modalities, "character")
-  expect_true("bulk" %in% modalities)
-  expect_true("single-cell" %in% modalities)
-})
-
-test_that("get_valid_query returns correct structure", {
-  query <- get_valid_query()
-  expect_type(query, "list")
-  expect_true("inputs" %in% names(query))
-  expect_true("mode" %in% names(query))
-  expect_true("modality" %in% names(query))
-  expect_type(query$inputs, "list")
-})
-
-test_that("get_valid_query supports modality parameter", {
-  query_bulk <- get_valid_query(modality = "bulk")
-  expect_equal(query_bulk$modality, "bulk")
-
-  query_sc <- get_valid_query(modality = "single-cell")
-  expect_equal(query_sc$modality, "single-cell")
-})
-
-test_that("validate_query passes for valid query", {
-  valid_query <- list(
-    inputs = list(
-      list(
-        metadata = list(
-          cell_line_ontology_id = "CVCL_0023",
-          perturbation_ontology_id = "ENSG00000156127",
-          perturbation_type = "crispr",
-          perturbation_time = "96 hours",
-          sample_type = "cell line"
-        ),
-        num_samples = 1
-      )
-    ),
-    modality = "bulk",
-    mode = "sample generation"
-  )
-
-  expect_invisible(validate_query(valid_query))
-})
-
-test_that("validate_query fails for missing keys", {
-  invalid_query <- list(
-    inputs = list(),
-    mode = "sample generation"
-  )
-
-  expect_error(
-    validate_query(invalid_query),
-    "Missing required keys in query.*modality"
-  )
-})
-
-test_that("validate_query fails for non-list input", {
-  expect_error(
-    validate_query("not a list"),
-    "Expected `query` to be a list"
-  )
-})
-
-test_that("validate_modality passes for valid modality", {
-  query <- list(
-    modality = "bulk",
-    mode = "x",
-    inputs = list()
-  )
-
-  expect_invisible(validate_modality(query))
-})
-
-test_that("validate_modality fails for invalid modality", {
-  query <- list(
-    modality = "invalid_modality",
-    mode = "x",
-    inputs = list()
-  )
-
-  expect_error(
-    validate_modality(query),
-    "Invalid modality 'invalid_modality'"
-  )
-})
-
-test_that("validate_modality fails for missing modality key", {
-  query <- list(
-    mode = "x",
-    inputs = list()
-  )
-
-  expect_error(
-    validate_modality(query),
-    "Query requires `modality` key"
-  )
-})
-
-# -----------------------------
-# Log CPM Tests
-# -----------------------------
-
-test_that("log_cpm transforms counts correctly", {
-  counts_data <- data.frame(
-    gene1 = c(1000000, 3000000),
-    gene2 = c(2000000, 6000000)
-  )
-
-  # R's log_cpm implementation uses t(t(expr) / library_size) which divides
-  # element-wise in column-cycling order, not row-wise
-  # library_size = c(3e6, 9e6) recycles as: [1,1]/lib[1], [2,1]/lib[2], [1,2]/lib[1], [2,2]/lib[2]
-  # After transpose: [1,1]=1e6/3e6, [1,2]=2e6/9e6, [2,1]=3e6/3e6, [2,2]=6e6/9e6
-  expected_log_cpm <- data.frame(
-    gene1 = c(log1p(1000000 / 3000000 * 1e6), log1p(3000000 / 3000000 * 1e6)),
-    gene2 = c(log1p(2000000 / 9000000 * 1e6), log1p(6000000 / 9000000 * 1e6))
-  )
-
-  result_log_cpm <- log_cpm(counts_data)
-
-  expect_equal(result_log_cpm$gene1, expected_log_cpm$gene1, tolerance = 1e-5)
-  expect_equal(result_log_cpm$gene2, expected_log_cpm$gene2, tolerance = 1e-5)
-})
-
-test_that("log_cpm handles zero counts", {
-  counts_data <- data.frame(
-    gene1 = c(10, 0),
-    gene2 = c(20, 0)
-  )
-
-  # library_size = c(30, 0)
-  # The R implementation's t(t(expr)/library_size) creates Inf/NaN for zero library sizes
-  # With column-cycling: [1,1]/30, [2,1]/0, [1,2]/30, [2,2]/0
-  # Result after transpose: [1,1]=10/30, [1,2]=20/0=Inf, [2,1]=0/30=0, [2,2]=0/0=NaN
-  result_log_cpm <- log_cpm(counts_data)
-
-  # Verify the first row is calculated correctly
-  expect_equal(result_log_cpm$gene1[1], log1p(10 / 30 * 1e6), tolerance = 1e-5)
-  # gene2 in row 1 gets divided by 0 due to column-recycling, resulting in Inf
-  expect_true(is.infinite(result_log_cpm$gene2[1]))
-
-  # For row 2: gene1 gets divided by 30 (column-recycle), gene2 by 0
-  expect_equal(result_log_cpm$gene1[2], 0.0)
-  expect_true(is.nan(result_log_cpm$gene2[2]))
-})
-
-# -----------------------------
-# Parameter Tests
-# -----------------------------
-
-test_that("predict_query passes as_counts parameter correctly", {
+test_that("list_models mock test", {
   original_api_key <- setup_test_environment()
   on.exit(restore_api_key(original_api_key))
 
-  mocks <- create_success_mocks(
-    query_id = "test-id",
-    download_url = "https://example.com/data.json",
-    counts_list = list(
-      c(100, 200, 300)
-    ),
-    metadata_df = data.frame(
-      sample_id = "test1"
-    ),
-    gene_order = c("gene1", "gene2", "gene3")
-  )
+  # Stub make_api_request to return mock data
+  stub(list_models, "make_api_request", function(url, context_msg) {
+    list(
+      list(id = "gem-1-bulk", name = "GEM-1 Bulk"),
+      list(id = "gem-1-sc", name = "GEM-1 Single Cell")
+    )
+  })
 
-  stub(predict_query, "has_synthesize_token", mocks$has_token)
-  stub(predict_query, "start_model_query", mocks$start_query)
-  stub(predict_query, "poll_model_query", mocks$poll)
-  stub(predict_query, "get_json", mocks$get_json)
+  result <- list_models()
+  expect_type(result, "list")
+  expect_true(length(result) > 0)
+})
 
-  query <- get_valid_query()
+test_that("get_example_query mock test", {
+  original_api_key <- setup_test_environment()
+  on.exit(restore_api_key(original_api_key))
 
-  # Test with as_counts = TRUE (should return raw counts)
-  result_counts <- predict_query(query, as_counts = TRUE)
-  expect_equal(as.numeric(result_counts$expression[1, ]), c(100, 200, 300))
+  # Stub make_api_request to return mock data
+  stub(get_example_query, "make_api_request", function(url, context_msg) {
+    list(
+      inputs = list(
+        list(
+          metadata = list(cell_type_ontology_id = "CL:0000786"),
+          num_samples = 5
+        )
+      ),
+      mode = "mean estimation"
+    )
+  })
 
-  # Test with as_counts = FALSE (should return log CPM transformed data)
-  result_log <- predict_query(query, as_counts = FALSE)
-  # Verify transformation was applied - values should be different from raw counts
-  expect_false(all(as.numeric(result_log$expression[1, ]) == c(100, 200, 300)))
-  # Values should be positive (log1p of positive numbers)
-  expect_true(all(result_log$expression >= 0))
+  result <- get_example_query(model_id = "gem-1-bulk")
+  expect_type(result, "list")
+  expect_true("inputs" %in% names(result))
+  expect_true("mode" %in% names(result))
 })
 
 # -----------------------------
